"""Custom command to generate auth data."""

from typing import Any, TextIO

from django.core.management.base import BaseCommand

from sage_otp.repository.generator import DataGeneratorLayer

DGL = DataGeneratorLayer()


class Command(BaseCommand):
    """
    Django management command for generating fake data for the otp app.

    Usage:
        python manage.py generate_otp_data
    """

    help = "Generate fake data for auth app."

    def handle(self, *args: Any, **kwargs: Any) -> str | TextIO | None:
        """
        Handle the command execution.

        Args:
            *args (Any): Additional arguments.
            **kwargs (Any): Additional keyword arguments.

        Returns:
            Union[str, TextIO, None]: A string, text output, or None.
        """
        # Arguments

        total = DGL.generate_otp_for_users()
        self.stdout.write(
            self.style.HTTP_NOT_MODIFIED(f"{total} OTP have been generated by machine.")
        )

    def show_success_msg(self, msg: str) -> TextIO:
        """Displays a success message on the console."""
        self.stdout.write(self.style.SUCCESS(msg))

    def show_error_msg(self, msg: str) -> TextIO:
        """Displays an error message on the console."""
        self.stdout.write(self.style.ERROR(msg))
